@@ -4,8 +4,8 @@ use warnings;
 use Plack::Request ();
 
 package Plack::Middleware::MethodOverride;
-
-our $VERSION = '0.19';
+$Plack::Middleware::MethodOverride::VERSION = '0.20';
+# ABSTRACT: Override REST methods to Plack apps via POST
 
 use parent 'Plack::Middleware';
 use Plack::Util::Accessor 'param';
@@ -51,11 +51,19 @@ sub header {
 
 __END__
 
-=head1 NAME
+=pod
+
+=encoding UTF-8
+
+=head1 Name
 
 Plack::Middleware::MethodOverride - Override REST methods to Plack apps via POST
 
-=head1 SYNOPSIS
+=head1 Version
+
+version 0.20
+
+=head1 Synopsis
 
 In your Plack app:
 
@@ -77,7 +85,7 @@ Or override it via the C<X-HTTP-Method-Override> header in a request:
       'X-HTTP-Method-Override' => 'PUT'
   ]);
 
-=head1 DESCRIPTION
+=head1 Description
 
 Writing
 L<REST|http://en.wikipedia.org/wiki/Representational_State_Transfer>ful apps
@@ -134,23 +142,6 @@ Specifies the query parameter name to specify the overriding HTTP method.
 
 Defaults to C<x-tunneled-method>.
 
-=head1 AUTHOR
-
-Tatsuhiko Miyagawa
-
-David E. Wheeler
-
-Aristotle Pagaltzis
-
-=head1 COPYRIGHT
-
-2015- Tatsuhiko Miyagawa, David E. Wheeler, Aristotle Pagaltzis
-
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 Acknowledgements
 
 This module gleefully steals from
@@ -162,4 +153,29 @@ S Trout|http://www.trout.me.uk/> for suggesting that it be implemented as
 middleware, and to L<Hans Dieter Pearcey|http://www.weftsoar.net/> for
 convincing me not to parse body parameters.
 
+=head1 Authors
+
+=over 4
+
+=item *
+
+Tatsuhiko Miyagawa <miyagawa@bulknews.net>
+
+=item *
+
+David E. Wheeler <david@justatheory.com>
+
+=item *
+
+Aristotle Pagaltzis <pagaltzis@gmx.de>
+
+=back
+
+=head1 Copyright and License
+
+This software is copyright (c) 2015 by Tatsuhiko Miyagawa, David E. Wheeler, Aristotle Pagaltzis.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
